#[non_exhaustive]pub enum ErrorClass {
Broken,
Transient,
Permanent,
}Expand description
Classification of a PostgreSQL error for retry/reconnection decisions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Broken
The connection is definitely broken. Must reconnect. Examples: ConnectionClosed, ConnectionReset, UnexpectedEof.
Transient
The error is transient and may resolve on retry. The connection is still alive. Examples: SerializationFailure, DeadlockDetected, Timeout.
Permanent
The error is permanent and will not resolve on retry. The connection is still alive. Examples: SyntaxError, PermissionDenied, UniqueViolation.