CommandTag

Struct CommandTag 

#[non_exhaustive]
pub struct CommandTag { /* private fields */ }
The command tag returned by PostgreSQL for a completed command (e.g. "SELECT 3", "INSERT 0 1", "UPDATE 4").

Implementations

Source

impl CommandTag

pub fn new(tag: String) -> Self

Create a new command tag from the raw string.

pub fn as_str(&self) -> &str

The raw tag string.

pub fn rows_affected(&self) -> Option<u64>

Parse the number of rows affected from the tag.

Returns None for commands that do not have a row count (e.g. CREATE TABLE).