#[non_exhaustive]pub struct CommandTag { /* private fields */ }Expand description
The command tag returned by PostgreSQL for a completed command
(e.g. "SELECT 3", "INSERT 0 1", "UPDATE 4").
Implementations
Sourceimpl CommandTag
impl CommandTag
Sourcepub fn rows_affected(&self) -> Option<u64>
pub fn rows_affected(&self) -> Option<u64>
Parse the number of rows affected from the tag.
Returns None for commands that do not have a row count
(e.g. CREATE TABLE).